<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Revised: 6/4/2009
// Revised layout for use-ability.
// Revised: 2/8/2012	ELL
// Added table prefix handling.
	
	include ("check_session.php");
?>
<html>
<head>
<title>Breeze Website Builder</title>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
<link rel="stylesheet" href="manager.css" type="text/css">
</head>

<body>
<form name="frmSelectPage" method="post" action="delete_page_confirm.php">
<table align="center" border="0"><tr>
<td align="center">Select the page you want to delete: 
    <select name="selectPage">
<?php
//	include "../connect/db_connection.php";
	
	$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data ORDER BY page_name";
	$result = $bwb_dbh->query($query);
	$num_results = $result->rowCount();
	for ($i == 1; $i < $num_results; $i++)
	{
		$row = $result->fetch(PDO::FETCH_ASSOC);
		$page_name = $row["page_name"];
		echo "<option value='$page_name'>$page_name</option>";
    }
?>
    </select>
	</td>
	<td><input type="submit" name="Submit" value="Delete"></td>
	 </tr></table>
	 </form>
<p align="center">
  
  <input type="button" name="Back" value="Back to Main Menu" onClick="window.location.href='main.php?mode=delete';">
 
</p>

<div align="center"></div>
</body>
</html>
